netapp_ontap.models.scanner_pool API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.scanner_pool`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ScannerPoolSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ScannerPool object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `cluster: Cluster GET POST PATCH`

    The cluster field of the scanner_pool.

  `name: str GET POST`

    Specifies the name of the scanner pool. Scanner pool name can be up to 256 characters long and is a string that can only contain any combination of ASCII-range alphanumeric characters a-z, A-Z, 0-9), "_", "-" and ".".

    Example: scanner-1

  `privileged_users: List[str] GET POST PATCH`

    Specifies a list of privileged users. A valid form of privileged user-name is "domain-name\user-name". Privileged user-names are stored and treated as case-insensitive strings. Virus scanners must use one of the registered privileged users for connecting to clustered Data ONTAP for exchanging virus-scanning protocol messages and to access file for scanning, remedying and quarantining operations.

    Example: ["cifs\u1","cifs\u2"]

  `role: str GET POST PATCH`

    Specifies the role of the scanner pool. The possible values are:

    - primary - Always active.
    - secondary - Active only when none of the primary external virus-scanning servers are connected.
    - idle - Always inactive.

    Valid choices:

    - primary
    - secondary
    - idle
  `servers: List[str] GET POST PATCH`

    Specifies a list of IP addresses or FQDN for each Vscan server host names which are allowed to connect to clustered ONTAP.

    Example: ["1.1.1.1","10.72.204.27","vmwin204-27.fsct.nb"]